aboutsummaryrefslogtreecommitdiff
path: root/include/datetime/timezones-live.h
diff options
context:
space:
mode:
authorIain Lane <iain.lane@canonical.com>2015-09-09 16:40:41 +0000
committerCI Train Bot <ci-train-bot@canonical.com>2015-09-09 16:40:41 +0000
commit13bcfccd0c9038c4b4c20c37c8d3267a5e6fbfee (patch)
tree30705f0a3f047a46020c7204397649ff2c609936 /include/datetime/timezones-live.h
parentad2d17a82ebe369adca6b477d5ecb362e243f585 (diff)
parentec001e64b2225a3c80b7e89d9a570728fcbca830 (diff)
downloadayatana-indicator-datetime-13bcfccd0c9038c4b4c20c37c8d3267a5e6fbfee.tar.gz
ayatana-indicator-datetime-13bcfccd0c9038c4b4c20c37c8d3267a5e6fbfee.tar.bz2
ayatana-indicator-datetime-13bcfccd0c9038c4b4c20c37c8d3267a5e6fbfee.zip
Remove warnings from test logs. Swallow the ones that are expected and fail the test if they don't show up. In addition, fail tests if unexpected warnings show up again.
Approved by: Charles Kerr
Diffstat (limited to 'include/datetime/timezones-live.h')
-rw-r--r--include/datetime/timezones-live.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/datetime/timezones-live.h b/include/datetime/timezones-live.h
index ca4ef31..b9d78a5 100644
--- a/include/datetime/timezones-live.h
+++ b/include/datetime/timezones-live.h
@@ -22,8 +22,8 @@
#include <datetime/settings.h>
#include <datetime/timezones.h>
-#include <datetime/timezone-file.h>
#include <datetime/timezone-geoclue.h>
+#include <datetime/timezone-timedated.h>
#include <memory> // shared_ptr<>
@@ -32,19 +32,19 @@ namespace indicator {
namespace datetime {
/**
* \brief #Timezones object that uses a #FileTimezone and #GeoclueTimezone
* to detect what timezone we're in
*/
class LiveTimezones: public Timezones
{
public:
- LiveTimezones(const std::shared_ptr<const Settings>& settings, const std::string& filename);
+ LiveTimezones(const std::shared_ptr<const Settings>& settings);
private:
void update_geolocation();
void update_timezones();
- FileTimezone m_file;
+ TimedatedTimezone m_file;
std::shared_ptr<const Settings> m_settings;
std::shared_ptr<GeoclueTimezone> m_geo;
};
@@ -32,19 +32,19 @@ namespace indicator {
namespace datetime {
/**
- * \brief #Timezones object that uses a #FileTimezone and #GeoclueTimezone
+ * \brief #Timezones object that uses a #TimedatedTimezone and #GeoclueTimezone
* to detect what timezone we're in
*/